==> haskell-servant-0.20.2-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant
version:              0.20.2
visibility:           public
id:                   servant-0.20.2-3DeBOF03IhJCKzwwzEJRBz
key:                  servant-0.20.2-3DeBOF03IhJCKzwwzEJRBz
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  a16c61610e84464073897f74004ec6e3
exposed:              True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes
    Servant.API.Description Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Fragment
    Servant.API.Generic Servant.API.Header Servant.API.HttpVersion
    Servant.API.IsSecure Servant.API.Modifiers Servant.API.NamedRoutes
    Servant.API.QueryParam Servant.API.QueryString Servant.API.Raw
    Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.Status Servant.API.Stream
    Servant.API.Sub Servant.API.TypeErrors Servant.API.TypeLevel
    Servant.API.UVerb Servant.API.UVerb.Union Servant.API.Vault
    Servant.API.Verbs Servant.API.WithNamedContext
    Servant.API.WithResource Servant.Links
    Servant.Test.ComprehensiveAPI Servant.Types.SourceT

import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-0.20.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-0.20.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-0.20.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant
hs-libraries:         HSservant-0.20.2-3DeBOF03IhJCKzwwzEJRBz
depends:
    QuickCheck-2.14.3-5xMqTFfEVh35pIkOsqqnaD
    aeson-2.1.2.1-17AWhWkbfJE926UMi0wPlA
    attoparsec-0.14.4-GkPzleiGSjl3NaBuhMDecM base-4.17.2.1
    bifunctors-5.6-KLcmucI6NacAyWgzCaf5ds bytestring-0.11.5.3
    case-insensitive-1.2.1.0-3jbMOlKTiDn4NCqaBZ47Ne
    constraints-0.13.4-CGjlnwfbS29627qTZcMK3P containers-0.6.7
    deepseq-1.4.8.0 http-api-data-0.5.1-6UskEvRLFLr314zFYq2DbR
    http-media-0.8.1.1-ItcyBqeN6FvInBd8kQTNKP
    http-types-0.12.4-6IzIilaA47l58TRShghvhm
    mmorph-1.2.0-3nIz0RIlBAUER45blfkK28 mtl-2.2.2
    network-uri-2.6.4.2-EjZpKZ4F93eKYvVi9AsGV0
    singleton-bool-0.1.7-D70XRkHP0H17VRNE9AczhM
    sop-core-0.5.0.2-6A7lf58QPy2GZuvhMdgskj text-2.0.2
    transformers-0.5.6.2 vault-0.3.1.5-7IYXvHzYZ2YB4ngUPrbbfY

haddock-interfaces:   /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html:         /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-0.20.2-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant
version:              0.20.2
visibility:           public
id:                   servant-0.20.2-1HNykePKiCA6OaCinbH7N0
key:                  servant-0.20.2-1HNykePKiCA6OaCinbH7N0
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  2c0e4c5ac81a4d3155b5b5d796a0fc3e
exposed:              True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes
    Servant.API.Description Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Fragment
    Servant.API.Generic Servant.API.Header Servant.API.HttpVersion
    Servant.API.IsSecure Servant.API.Modifiers Servant.API.NamedRoutes
    Servant.API.QueryParam Servant.API.QueryString Servant.API.Raw
    Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.Status Servant.API.Stream
    Servant.API.Sub Servant.API.TypeErrors Servant.API.TypeLevel
    Servant.API.UVerb Servant.API.UVerb.Union Servant.API.Vault
    Servant.API.Verbs Servant.API.WithNamedContext
    Servant.API.WithResource Servant.Links
    Servant.Test.ComprehensiveAPI Servant.Types.SourceT

import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-0.20.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-0.20.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-0.20.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant
hs-libraries:         HSservant-0.20.2-1HNykePKiCA6OaCinbH7N0
depends:
    QuickCheck-2.14.3-GIUqI8qD1o41rCLRe3Qcl2
    aeson-2.1.2.1-CJUEk8Q0QXZ63rfmeHQCzY
    attoparsec-0.14.4-HJXsa8cMY97Lp9qL0m21oG base-4.17.2.1
    bifunctors-5.6-5KrJJWXN6lQKV6QHE4OSXU bytestring-0.11.5.3
    case-insensitive-1.2.1.0-FUjVpmJeiVFCvFoDLJPawp
    constraints-0.13.4-DUAIUCAwagkJCoPHyp2lLS containers-0.6.7
    deepseq-1.4.8.0 http-api-data-0.5.1-6POEPh2rLQeLoW1mJOUlIQ
    http-media-0.8.1.1-G8TuL8QE9dnGqTxSBz9ZC7
    http-types-0.12.4-BDoys3Aesb9DkjEWopUdY6
    mmorph-1.2.0-3nIz0RIlBAUER45blfkK28 mtl-2.2.2
    network-uri-2.6.4.2-BSIANA0b7f4FqAKAmElYJ
    singleton-bool-0.1.7-D70XRkHP0H17VRNE9AczhM
    sop-core-0.5.0.2-6A7lf58QPy2GZuvhMdgskj text-2.0.2
    transformers-0.5.6.2 vault-0.3.1.5-A631H6yr9D2EX40n7Zi8dS

haddock-interfaces:   /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html:         /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
